<?xml version="1.0" encoding="utf-8"?>
<xsl:stylesheet
    xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
    xmlns:fo="http://www.w3.org/1999/XSL/Format"
    version="1.0">

    <xsl:template match="/">
        <fo:root>
            <fo:layout-master-set>
                <fo:simple-page-master master-name="my-page">
                    <fo:region-body margin="1cm"/>
                </fo:simple-page-master>
            </fo:layout-master-set>

            <fo:page-sequence master-reference="my-page">
                <fo:flow flow-name="xsl-region-body">
                    <xsl:apply-templates/>
                </fo:flow>
            </fo:page-sequence>
        </fo:root>
    </xsl:template>

    <xsl:template match="Title">
        <fo:block font-weight="bold" space-after="10pt">
            <h2><xsl:apply-templates/></h2>
        </fo:block>
    </xsl:template>

    <xsl:template match="Figure">
        <img style="display: block; margin-left: auto; margin-right: auto; width: 30%;">
            <xsl:attribute name="src">
                <xsl:apply-templates/>
            </xsl:attribute>
        </img>
    </xsl:template>

    <xsl:template match="Section">
        <fo:block space-after="10pt">
            <h3><xsl:value-of select="@id"/></h3>
            <p>
                <xsl:call-template name="split-on-newline">
                    <xsl:with-param name="string" select="."/>
                </xsl:call-template>
            </p>
        </fo:block>
    </xsl:template>

    <xsl:template name="split-on-newline">
        <xsl:param name="string"/>
        <xsl:choose>
            <xsl:when test="contains($string, '&#xA;')">
                <xsl:value-of select="substring-before($string, '&#xA;')"/>
                <br/>
                <xsl:call-template name="split-on-newline">
                    <xsl:with-param name="string" select="substring-after($string, '&#xA;')"/>
                </xsl:call-template>
            </xsl:when>
            <xsl:otherwise>
                <xsl:value-of select="$string"/>
                <br/>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>

</xsl:stylesheet>